@@ -2,7 +2,7 @@
  *
  * This file is part of Mapnik (c++ mapping toolkit)
  *
- * Copyright (C) 2024 Artem Pavlenko
+ * Copyright (C) 2025 Artem Pavlenko
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -53,9 +53,9 @@ class MAPNIK_DECL text_placement_info_list : public text_placement_info
 {
   public:
     text_placement_info_list(text_placements_list const* parent, double _scale_factor)
-        : text_placement_info(parent, _scale_factor)
-        , state(0)
-        , parent_(parent)
+        : text_placement_info(parent, _scale_factor),
+          state(0),
+          parent_(parent)
     {}
     bool next() const;
 
