@@ -91,7 +91,7 @@ class csv_datasource : public mapnik::datasource,
     csv_datasource(mapnik::parameters const& params);
     virtual ~csv_datasource();
     mapnik::datasource::datasource_t type() const override;
-    static const char* name();
+    static char const* name();
     mapnik::featureset_ptr features(mapnik::query const& q) const override;
     mapnik::featureset_ptr features_at_point(mapnik::coord2d const& pt, double tol = 0) const override;
     mapnik::box2d<double> envelope() const override;
