@@ -44,13 +44,13 @@ class ConnectionCreator
 {
   public:
     ConnectionCreator(mapnik::parameters const& params)
-        : host_{params.get<std::string>("host")}
-        , port_{params.get<std::string>("port")}
-        , dbname_{params.get<std::string>("dbname")}
-        , user_{params.get<std::string>("user")}
-        , password_{params.get<std::string>("password")}
-        , connect_timeout_{params.get<std::string>("connect_timeout", "4")}
-        , application_name_{params.get<std::string>("application_name")}
+        : host_{params.get<std::string>("host")},
+          port_{params.get<std::string>("port")},
+          dbname_{params.get<std::string>("dbname")},
+          user_{params.get<std::string>("user")},
+          password_{params.get<std::string>("password")},
+          connect_timeout_{params.get<std::string>("connect_timeout", "4")},
+          application_name_{params.get<std::string>("application_name")}
     {}
 
     T* operator()() const { return new T(connection_string_safe(), password_); }
@@ -153,15 +153,15 @@ class ConnectionManager : public singleton<ConnectionManager, CreateStatic>
         {
             return itr->second;
         }
-        static const std::shared_ptr<PoolType> emptyPool;
+        static std::shared_ptr<PoolType> const emptyPool;
         return emptyPool;
     }
 
     ConnectionManager() {}
 
   private:
-    ConnectionManager(const ConnectionManager&);
-    ConnectionManager& operator=(const ConnectionManager);
+    ConnectionManager(ConnectionManager const&);
+    ConnectionManager& operator=(ConnectionManager const);
 };
 
 #endif // POSTGIS_CONNECTION_MANAGER_HPP
