@@ -65,7 +65,7 @@ class topojson_datasource : public mapnik::datasource
     topojson_datasource(mapnik::parameters const& params);
     virtual ~topojson_datasource();
     mapnik::datasource::datasource_t type() const override;
-    static const char* name();
+    static char const* name();
     mapnik::featureset_ptr features(mapnik::query const& q) const override;
     mapnik::featureset_ptr features_at_point(mapnik::coord2d const& pt, double tol = 0) const override;
     mapnik::box2d<double> envelope() const override;
