@@ -37,14 +37,14 @@ void agg_renderer<T0, T1>::process(shield_symbolizer const& sym,
                                    mapnik::feature_impl& feature,
                                    proj_transform const& prj_trans)
 {
-    const box2d<double> clip_box = clipping_extent(common_);
+    box2d<double> const clip_box = clipping_extent(common_);
     agg::trans_affine tr;
-    const auto transform = get_optional<transform_type>(sym, keys::geometry_transform);
+    auto const transform = get_optional<transform_type>(sym, keys::geometry_transform);
     if (transform)
         evaluate_transform(tr, feature, common_.vars_, *transform, common_.scale_factor_);
     if (!mapnik::get<text_placements_ptr>(sym, keys::text_placements_))
         return;
-    const text_symbolizer_helper helper(sym,
+    text_symbolizer_helper const helper(sym,
                                         feature,
                                         common_.vars_,
                                         prj_trans,
@@ -57,13 +57,13 @@ void agg_renderer<T0, T1>::process(shield_symbolizer const& sym,
                                         clip_box,
                                         tr);
 
-    const halo_rasterizer_enum halo_rasterizer = get<halo_rasterizer_enum>(sym,
+    halo_rasterizer_enum const halo_rasterizer = get<halo_rasterizer_enum>(sym,
                                                                            keys::halo_rasterizer,
                                                                            feature,
                                                                            common_.vars_,
                                                                            halo_rasterizer_enum::HALO_RASTERIZER_FULL);
-    const composite_mode_e comp_op = get<composite_mode_e>(sym, keys::comp_op, feature, common_.vars_, src_over);
-    const composite_mode_e halo_comp_op =
+    composite_mode_e const comp_op = get<composite_mode_e>(sym, keys::comp_op, feature, common_.vars_, src_over);
+    composite_mode_e const halo_comp_op =
       get<composite_mode_e>(sym, keys::halo_comp_op, feature, common_.vars_, src_over);
     agg_text_renderer<T0> ren(buffers_.top().get(),
                               halo_rasterizer,
@@ -72,12 +72,12 @@ void agg_renderer<T0, T1>::process(shield_symbolizer const& sym,
                               common_.scale_factor_,
                               common_.font_manager_.get_stroker());
 
-    const double opacity = get<double>(sym, keys::opacity, feature, common_.vars_, 1.0);
+    double const opacity = get<double>(sym, keys::opacity, feature, common_.vars_, 1.0);
 
     placements_list const& placements = helper.get();
     for (auto const& glyphs : placements)
     {
-        const marker_info_ptr mark = glyphs->get_marker();
+        marker_info_ptr const mark = glyphs->get_marker();
         if (mark)
         {
             render_marker(glyphs->marker_pos(), *mark->marker_, mark->transform_, opacity, comp_op);
