@@ -54,12 +54,12 @@ cairo_renderer<T>::cairo_renderer(Map const& m,
                                   double scale_factor,
                                   unsigned offset_x,
                                   unsigned offset_y)
-    : feature_style_processor<cairo_renderer>(m, scale_factor)
-    , m_(m)
-    , context_(cairo)
-    , common_(m, attributes(), offset_x, offset_y, m.width(), m.height(), scale_factor)
-    , face_manager_(common_.shared_font_library_)
-    , style_level_compositing_(false)
+    : feature_style_processor<cairo_renderer>(m, scale_factor),
+      m_(m),
+      context_(cairo),
+      common_(m, attributes(), offset_x, offset_y, m.width(), m.height(), scale_factor),
+      face_manager_(common_.shared_font_library_),
+      style_level_compositing_(false)
 {
     setup(m);
 }
@@ -72,12 +72,12 @@ cairo_renderer<T>::cairo_renderer(Map const& m,
                                   double scale_factor,
                                   unsigned offset_x,
                                   unsigned offset_y)
-    : feature_style_processor<cairo_renderer>(m, scale_factor)
-    , m_(m)
-    , context_(cairo)
-    , common_(m, req, vars, offset_x, offset_y, req.width(), req.height(), scale_factor)
-    , face_manager_(common_.shared_font_library_)
-    , style_level_compositing_(false)
+    : feature_style_processor<cairo_renderer>(m, scale_factor),
+      m_(m),
+      context_(cairo),
+      common_(m, req, vars, offset_x, offset_y, req.width(), req.height(), scale_factor),
+      face_manager_(common_.shared_font_library_),
+      style_level_compositing_(false)
 
 {
     setup(m);
@@ -90,12 +90,12 @@ cairo_renderer<T>::cairo_renderer(Map const& m,
                                   double scale_factor,
                                   unsigned offset_x,
                                   unsigned offset_y)
-    : feature_style_processor<cairo_renderer>(m, scale_factor)
-    , m_(m)
-    , context_(cairo)
-    , common_(m, attributes(), offset_x, offset_y, m.width(), m.height(), scale_factor, detector)
-    , face_manager_(common_.shared_font_library_)
-    , style_level_compositing_(false)
+    : feature_style_processor<cairo_renderer>(m, scale_factor),
+      m_(m),
+      context_(cairo),
+      common_(m, attributes(), offset_x, offset_y, m.width(), m.height(), scale_factor, detector),
+      face_manager_(common_.shared_font_library_),
+      style_level_compositing_(false)
 
 {
     setup(m);
@@ -108,8 +108,8 @@ cairo_renderer<T>::~cairo_renderer()
 struct setup_marker_visitor
 {
     setup_marker_visitor(cairo_context& context, renderer_common const& common)
-        : context_(context)
-        , common_(common)
+        : context_(context),
+          common_(common)
     {}
 
     void operator()(marker_null const&) const {}
@@ -118,13 +118,13 @@ struct setup_marker_visitor
     void operator()(marker_rgba8 const& marker) const
     {
         mapnik::image_rgba8 const& bg_image = marker.get_data();
-        const std::size_t w = bg_image.width();
-        const std::size_t h = bg_image.height();
+        std::size_t const w = bg_image.width();
+        std::size_t const h = bg_image.height();
         if (w > 0 && h > 0)
         {
             // repeat background-image both vertically and horizontally
-            const std::size_t x_steps = std::size_t(std::ceil(common_.width_ / double(w)));
-            const std::size_t y_steps = std::size_t(std::ceil(common_.height_ / double(h)));
+            std::size_t const x_steps = std::size_t(std::ceil(common_.width_ / double(w)));
+            std::size_t const y_steps = std::size_t(std::ceil(common_.height_ / double(h)));
             for (std::size_t x = 0; x < x_steps; ++x)
             {
                 for (std::size_t y = 0; y < y_steps; ++y)
@@ -144,7 +144,7 @@ struct setup_marker_visitor
 template<typename T>
 void cairo_renderer<T>::setup(Map const& map)
 {
-    const auto bg = m_.background();
+    auto const bg = m_.background();
     if (bg.has_value())
     {
         cairo_save_restore guard(context_);
@@ -166,7 +166,7 @@ template<typename T>
 void cairo_renderer<T>::start_map_processing(Map const& map)
 {
     MAPNIK_LOG_DEBUG(cairo_renderer) << "cairo_renderer: Start map processing bbox=" << map.get_current_extent();
-    const box2d<double> bounds = common_.t_.forward(common_.t_.extent());
+    box2d<double> const bounds = common_.t_.forward(common_.t_.extent());
     context_.rectangle(bounds.minx(), bounds.miny(), bounds.maxx(), bounds.maxy());
     context_.clip();
 }
@@ -245,12 +245,12 @@ struct cairo_render_marker_visitor
                                 agg::trans_affine const& tr,
                                 double opacity,
                                 bool recenter)
-        : context_(context)
-        , common_(common)
-        , pos_(pos)
-        , tr_(tr)
-        , opacity_(opacity)
-        , recenter_(recenter)
+        : context_(context),
+          common_(common),
+          pos_(pos),
+          tr_(tr),
+          opacity_(opacity),
+          recenter_(recenter)
     {}
 
     void operator()(marker_null const&) {}
