@@ -43,7 +43,7 @@ class jpeg_reader : public image_reader
   public:
     using source_type = T;
     using input_stream = std::iostream;
-    const static unsigned BUF_SIZE = 4096;
+    static unsigned const BUF_SIZE = 4096;
 
   private:
     struct jpeg_stream_wrapper
@@ -102,17 +102,17 @@ image_reader* create_jpeg_reader2(char const* data, size_t size)
 }
 void register_jpeg_reader()
 {
-    [[maybe_unused]] const bool registered = register_image_reader("jpeg", create_jpeg_reader);
-    [[maybe_unused]] const bool registered2 = register_image_reader("jpeg", create_jpeg_reader2);
+    [[maybe_unused]] bool const registered = register_image_reader("jpeg", create_jpeg_reader);
+    [[maybe_unused]] bool const registered2 = register_image_reader("jpeg", create_jpeg_reader2);
 }
 
 // ctors
 template<typename T>
 jpeg_reader<T>::jpeg_reader(std::string const& filename)
-    : source_()
-    , stream_(&source_)
-    , width_(0)
-    , height_(0)
+    : source_(),
+      stream_(&source_),
+      width_(0),
+      height_(0)
 {
     source_.open(filename, std::ios_base::in | std::ios_base::binary);
     if (!stream_)
@@ -122,10 +122,10 @@ jpeg_reader<T>::jpeg_reader(std::string const& filename)
 
 template<typename T>
 jpeg_reader<T>::jpeg_reader(char const* data, size_t size)
-    : source_(data, size)
-    , stream_(&source_)
-    , width_(0)
-    , height_(0)
+    : source_(data, size),
+      stream_(&source_),
+      width_(0),
+      height_(0)
 {
     if (!stream_)
         throw image_reader_exception("cannot open image stream");
@@ -289,10 +289,10 @@ void jpeg_reader<T>::read(unsigned x0, unsigned y0, image_rgba8& image)
     row_stride = cinfo.output_width * cinfo.output_components;
     buffer = (*cinfo.mem->alloc_sarray)((j_common_ptr)&cinfo, JPOOL_IMAGE, row_stride, 1);
 
-    const unsigned w = std::min(unsigned(image.width()), width_ - x0);
-    const unsigned h = std::min(unsigned(image.height()), height_ - y0);
+    unsigned const w = std::min(unsigned(image.width()), width_ - x0);
+    unsigned const h = std::min(unsigned(image.height()), height_ - y0);
 
-    const std::unique_ptr<unsigned int[]> out_row(new unsigned int[w]);
+    std::unique_ptr<unsigned int[]> const out_row(new unsigned int[w]);
     unsigned row = 0;
     while (cinfo.output_scanline < cinfo.output_height)
     {
