@@ -30,7 +30,7 @@ namespace util {
 bool to_geojson(std::string& json, mapnik::geometry::geometry<double> const& geom)
 {
     using sink_type = std::back_insert_iterator<std::string>;
-    static const mapnik::json::geometry_generator_grammar<sink_type, mapnik::geometry::geometry<double>> grammar;
+    static mapnik::json::geometry_generator_grammar<sink_type, mapnik::geometry::geometry<double>> const grammar;
     sink_type sink(json);
     return boost::spirit::karma::generate(sink, grammar, geom);
 }
