@@ -33,7 +33,7 @@ namespace detail {
 struct twkb_reader : mapnik::util::noncopyable
 {
   private:
-    const char* twkb_;
+    char const* twkb_;
     size_t size_;
     unsigned int pos_;
     // Metadata on the geometry we are parsing
@@ -66,28 +66,19 @@ struct twkb_reader : mapnik::util::noncopyable
     };
 
     twkb_reader(char const* twkb, size_t size)
-        : twkb_(twkb)
-        , size_(size)
-        , pos_(0)
-        , twkb_type_(0)
-        , // Geometry type
-        has_bbox_(0)
-        , // Bounding box?
-        has_size_(0)
-        , // Size attribute?
-        has_idlist_(0)
-        , // Presence of X/Y
-        has_z_(0)
-        , // Presence of Z
-        has_m_(0)
-        , // Presence of M
-        is_empty_(0)
-        , // Empty?
-        factor_xy_(0.0)
-        , // Expansion factor for X/Y
-        factor_z_(0.0)
-        ,              // Expansion factor for Z
-        factor_m_(0.0) // Expansion factor for M
+        : twkb_(twkb),
+          size_(size),
+          pos_(0),
+          twkb_type_(0),   // Geometry type
+          has_bbox_(0),    // Bounding box?
+          has_size_(0),    // Size attribute?
+          has_idlist_(0),  // Presence of X/Y
+          has_z_(0),       // Presence of Z
+          has_m_(0),       // Presence of M
+          is_empty_(0),    // Empty?
+          factor_xy_(0.0), // Expansion factor for X/Y
+          factor_z_(0.0),  // Expansion factor for Z
+          factor_m_(0.0)   // Expansion factor for M
     {}
 
     mapnik::geometry::geometry<double> read()
@@ -392,7 +383,7 @@ struct twkb_reader : mapnik::util::noncopyable
 
 } // namespace detail
 
-mapnik::geometry::geometry<double> geometry_utils::from_twkb(const char* wkb, std::size_t size)
+mapnik::geometry::geometry<double> geometry_utils::from_twkb(char const* wkb, std::size_t size)
 {
     detail::twkb_reader reader(wkb, size);
     mapnik::geometry::geometry<double> geom(reader.read());
