@@ -31,8 +31,8 @@ namespace geometry {
 // point adapter
 template<typename T>
 point_vertex_adapter<T>::point_vertex_adapter(point<T> const& pt)
-    : pt_(pt)
-    , first_(true)
+    : pt_(pt),
+      first_(true)
 {}
 
 template<typename T>
@@ -63,9 +63,9 @@ geometry_types point_vertex_adapter<T>::type() const
 // line_string adapter
 template<typename T>
 line_string_vertex_adapter<T>::line_string_vertex_adapter(line_string<T> const& line)
-    : line_(line)
-    , current_index_(0)
-    , end_index_(line.size())
+    : line_(line),
+      current_index_(0),
+      end_index_(line.size())
 {}
 
 template<typename T>
@@ -102,12 +102,12 @@ geometry_types line_string_vertex_adapter<T>::type() const
 
 template<typename T>
 polygon_vertex_adapter<T>::polygon_vertex_adapter(polygon<T> const& poly)
-    : poly_(poly)
-    , rings_itr_(0)
-    , rings_end_(poly_.size())
-    , current_index_(0)
-    , end_index_(poly_.empty() ? 0 : poly_[0].size())
-    , start_loop_(true)
+    : poly_(poly),
+      rings_itr_(0),
+      rings_end_(poly_.size()),
+      current_index_(0),
+      end_index_(poly_.empty() ? 0 : poly_[0].size()),
+      start_loop_(true)
 {}
 
 template<typename T>
@@ -171,10 +171,10 @@ geometry_types polygon_vertex_adapter<T>::type() const
 // ring adapter
 template<typename T>
 ring_vertex_adapter<T>::ring_vertex_adapter(linear_ring<T> const& ring)
-    : ring_(ring)
-    , current_index_(0)
-    , end_index_(ring_.size())
-    , start_loop_(true)
+    : ring_(ring),
+      current_index_(0),
+      end_index_(ring_.size()),
+      start_loop_(true)
 {}
 
 template<typename T>
